@@ -48,6 +48,10 @@ QWaylandLayerSurface::QWaylandLayerSurface(QWaylandLayerShellIntegration *shell,
     connect(m_interface, &Window::exclusionZoneChanged, this, [this]() {
         setExclusiveZone(m_interface->exclusionZone());
     });
+    setExclusiveEdge(m_interface->exclusiveEdge());
+    connect(m_interface, &Window::exclusiveEdgeChanged, this, [this]() {
+        setExclusiveEdge(m_interface->exclusiveEdge());
+    });
 
     setMargins(m_interface->margins());
     connect(m_interface, &Window::marginsChanged, this, [this]() {
@@ -127,6 +131,13 @@ void QWaylandLayerSurface::setExclusiveZone(int32_t zone)
     set_exclusive_zone(zone);
 }
 
+void QWaylandLayerSurface::setExclusiveEdge(uint32_t edge)
+{
+    if (zwlr_layer_surface_v1_get_version(object()) >= ZWLR_LAYER_SURFACE_V1_SET_EXCLUSIVE_EDGE_SINCE_VERSION) {
+        set_exclusive_edge(edge);
+    }
+}
+
 void QWaylandLayerSurface::setMargins(const QMargins &margins)
 {
     set_margin(margins.top(), margins.right(), margins.bottom(), margins.left());
